pygeai.tests.snippets.organization package
==========================================

Submodules
----------

pygeai.tests.snippets.organization.create\_project module
---------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.create_project
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.delete\_project module
---------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.delete_project
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.export\_request\_data module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.export_request_data
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.get\_memberships module
----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.get_memberships
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.get\_organization\_members module
--------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.get_organization_members
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.get\_project\_data module
------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.get_project_data
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.get\_project\_list module
------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.get_project_list
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.get\_project\_members module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.get_project_members
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.get\_project\_memberships module
-------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.get_project_memberships
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.get\_project\_roles module
-------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.get_project_roles
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.get\_project\_tokens module
--------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.get_project_tokens
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.organization.update\_project module
---------------------------------------------------------

.. automodule:: pygeai.tests.snippets.organization.update_project
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.organization
   :members:
   :show-inheritance:
   :undoc-members:
